@@ -13,6 +13,7 @@ API_PATH = {
     "about_traffic":           "r/{subreddit}/about/traffic/",
     "about_unmoderated":       "r/{subreddit}/about/unmoderated/",
     "accept_mod_invite":       "r/{subreddit}/api/accept_moderator_invite",
+    "add_subreddit_rule":      "api/add_subreddit_rule",
     "approve":                 "api/approve/",
     "block":                   "api/block",
     "block_user":              "/api/block_user/",
@@ -139,7 +140,9 @@ API_PATH = {
     "removal_reasons":         "api/v1/modactions/removal_reasons",
     "removal_reason":          "api/v1/{subreddit}/removal_reasons/{id}",
     "removal_reasons_list":    "api/v1/{subreddit}/removal_reasons",
+    "remove_subreddit_rule":   "api/remove_subreddit_rule",
     "remove":                  "api/remove/",
+    "reorder_subreddit_rules": "api/reorder_subreddit_rules",
     "report":                  "api/report/",
     "rules":                   "r/{subreddit}/about/rules",
     "save":                    "api/save/",
@@ -160,6 +163,7 @@ API_PATH = {
     "submission":              "comments/{id}/",
     "submission_replies":      "message/selfreply/",
     "submit":                  "api/submit/",
+    "submit_poll_post":        "api/submit_poll_post",
     "subreddit":               "r/{subreddit}/",
     "subreddit_about":         "r/{subreddit}/about/",
     "subreddit_filter":        "api/filter/user/{user}/f/{special}/r/{subreddit}",
@@ -188,6 +192,8 @@ API_PATH = {
     "unread_message":          "api/unread_message/",
     "unsave":                  "api/unsave/",
     "unspoiler":               "api/unspoiler/",
+    "update_settings":         "api/v1/subreddit/update_settings",
+    "update_subreddit_rule":   "api/update_subreddit_rule",
     "upload_image":            "r/{subreddit}/api/upload_sr_img",
     "user":                    "user/{user}/",
     "user_about":              "user/{user}/about/",
