@@ -1,16 +1,17 @@
 """Provide the DomainListing class."""
-from typing import TypeVar
+from typing import TYPE_CHECKING
 
 from ...const import API_PATH
 from .mixins import BaseListingMixin, RisingListingMixin
 
-Reddit = TypeVar("Reddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
 
 
 class DomainListing(BaseListingMixin, RisingListingMixin):
     """Provide a set of functions to interact with domain listings."""
 
-    def __init__(self, reddit: Reddit, domain: str):
+    def __init__(self, reddit: "Reddit", domain: str):
         """Initialize a DomainListing instance.
 
         :param reddit: An instance of Reddit.
