@@ -1,5 +1,5 @@
 """Provide the RedditorListingMixin class."""
-from typing import Any, Dict, Generator, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Iterator, Union
 from urllib.parse import urljoin
 
 from ....util.cache import cachedproperty
@@ -7,13 +7,14 @@ from ..generator import ListingGenerator
 from .base import BaseListingMixin
 from .gilded import GildedListingMixin
 
-Reddit = TypeVar("Reddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
 
 
 class SubListing(BaseListingMixin):
     """Helper class for generating :class:`.ListingGenerator` objects."""
 
-    def __init__(self, reddit: Reddit, base_path: str, subpath: str):
+    def __init__(self, reddit: "Reddit", base_path: str, subpath: str):
         """Initialize a SubListing instance.
 
         :param reddit: An instance of :class:`.Reddit`.
@@ -39,8 +40,8 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
 
         .. code-block:: python
 
-           for comment in reddit.redditor('spez').comments.new(limit=None):
-               print(comment.body.split('\n', 1)[0][:79])
+           for comment in reddit.redditor("spez").comments.new(limit=None):
+               print(comment.body.split("\n", 1)[0][:79])
 
         """
         return SubListing(self._reddit, self._path, "comments")
@@ -54,7 +55,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
 
         .. code-block:: python
 
-           for submission in reddit.redditor('spez').submissions.top('all'):
+           for submission in reddit.redditor("spez").submissions.top("all"):
                print(submission.title)
 
         """
@@ -62,7 +63,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
 
     def downvoted(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Any, None, None]:
+    ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for items the user has downvoted.
 
         May raise ``prawcore.Forbidden`` after issuing the request if the user
@@ -87,7 +88,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
 
     def gildings(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Any, None, None]:
+    ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for items the user has gilded.
 
         May raise ``prawcore.Forbidden`` after issuing the request if the user
@@ -107,14 +108,12 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
 
         """
         return ListingGenerator(
-            self._reddit,
-            urljoin(self._path, "gilded/given"),
-            **generator_kwargs
+            self._reddit, urljoin(self._path, "gilded/given"), **generator_kwargs
         )
 
     def hidden(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Any, None, None]:
+    ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for items the user has hidden.
 
         May raise ``prawcore.Forbidden`` after issuing the request if the user
@@ -139,7 +138,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
 
     def saved(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Any, None, None]:
+    ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for items the user has saved.
 
         May raise ``prawcore.Forbidden`` after issuing the request if the user
@@ -164,7 +163,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
 
     def upvoted(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Any, None, None]:
+    ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for items the user has upvoted.
 
         May raise ``prawcore.Forbidden`` after issuing the request if the user
