@@ -1,5 +1,5 @@
 """Provide the SubredditListingMixin class."""
-from typing import Any, Dict, Generator, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Iterator, Optional, Union
 from urllib.parse import urljoin
 
 from ....util.cache import cachedproperty
@@ -9,26 +9,27 @@ from .base import BaseListingMixin
 from .gilded import GildedListingMixin
 from .rising import RisingListingMixin
 
-Comment = TypeVar("Comment")
-Reddit = TypeVar("Reddit")
-Subreddit = TypeVar("Subreddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from .... import Reddit
+    from ...reddit.comment import Comment  # noqa: F401
+    from ...reddit.subreddit import Subreddit
 
 
 class CommentHelper(PRAWBase):
     """Provide a set of functions to interact with a subreddit's comments."""
 
     @property
-    def _path(self):
+    def _path(self) -> str:
         return urljoin(self.subreddit._path, "comments/")
 
-    def __init__(self, subreddit: Subreddit):
+    def __init__(self, subreddit: "Subreddit"):
         """Initialize a CommentHelper instance."""
         super().__init__(subreddit._reddit, _data=None)
         self.subreddit = subreddit
 
     def __call__(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Any, None, None]:
+    ) -> Iterator["Comment"]:
         """Return a :class:`.ListingGenerator` for the Subreddit's comments.
 
         Additional keyword arguments are passed in the initialization of
@@ -38,16 +39,14 @@ class CommentHelper(PRAWBase):
 
         .. code-block:: python
 
-           for comment in reddit.subreddit('redditdev').comments(limit=25):
+           for comment in reddit.subreddit("redditdev").comments(limit=25):
                print(comment.author)
 
         """
         return ListingGenerator(self._reddit, self._path, **generator_kwargs)
 
 
-class SubredditListingMixin(
-    BaseListingMixin, GildedListingMixin, RisingListingMixin
-):
+class SubredditListingMixin(BaseListingMixin, GildedListingMixin, RisingListingMixin):
     """Adds additional methods pertaining to Subreddit-like instances."""
 
     @cachedproperty
@@ -59,13 +58,13 @@ class SubredditListingMixin(
 
         .. code-block:: python
 
-           for comment in reddit.subreddit('redditdev').comments(limit=25):
+           for comment in reddit.subreddit("redditdev").comments(limit=25):
                print(comment.author)
 
         """
         return CommentHelper(self)
 
-    def __init__(self, reddit: Reddit, _data: Dict[str, Any]):
+    def __init__(self, reddit: "Reddit", _data: Optional[Dict[str, Any]]):
         """Initialize a SubredditListingMixin instance.
 
         :param reddit: An instance of :class:`.Reddit`.
