@@ -1,11 +1,12 @@
 """Provide the RedditBase class."""
-from typing import Any, Dict, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Optional, Union
 from urllib.parse import urlparse
 
 from ...exceptions import InvalidURL
 from ..base import PRAWBase
 
-Reddit = TypeVar("Reddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
 
 
 class RedditBase(PRAWBase):
@@ -42,7 +43,7 @@ class RedditBase(PRAWBase):
         """Return the hash of the current instance."""
         return hash(self.__class__.__name__) ^ hash(str(self).lower())
 
-    def __init__(self, reddit: Reddit, _data: Dict[str, Any]):
+    def __init__(self, reddit: "Reddit", _data: Optional[Dict[str, Any]]):
         """Initialize a RedditBase instance (or a subclass).
 
         :param reddit: An instance of :class:`~.Reddit`.
@@ -53,9 +54,7 @@ class RedditBase(PRAWBase):
 
     def __repr__(self) -> str:
         """Return an object initialization representation of the instance."""
-        return "{}({}={!r})".format(
-            self.__class__.__name__, self.STR_FIELD, str(self)
-        )
+        return "{}({}={!r})".format(self.__class__.__name__, self.STR_FIELD, str(self))
 
     def __str__(self) -> str:
         """Return a string representation of the instance."""
