@@ -1,14 +1,14 @@
 """Provide the Emoji class."""
 import os
-from typing import Any, Dict, List, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 from ...const import API_PATH
 from ...exceptions import ClientException
 from .base import RedditBase
 
-_Emoji = TypeVar("_Emoji")
-Reddit = TypeVar("Reddit")
-Subreddit = TypeVar("Subreddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
+    from .subreddit import Subreddit
 
 
 class Emoji(RedditBase):
@@ -36,28 +36,22 @@ class Emoji(RedditBase):
 
     STR_FIELD = "name"
 
-    def __eq__(self, other: Union[str, _Emoji]) -> bool:
+    def __eq__(self, other: Union[str, "Emoji"]) -> bool:
         """Return whether the other instance equals the current."""
         if isinstance(other, str):
             return other == str(self)
         if isinstance(other, self.__class__):
-            return (
-                str(self) == str(other) and other.subreddit == self.subreddit
-            )
+            return str(self) == str(other) and other.subreddit == self.subreddit
         return super().__eq__(other)
 
     def __hash__(self) -> int:
         """Return the hash of the current instance."""
-        return (
-            hash(self.__class__.__name__)
-            ^ hash(str(self))
-            ^ hash(self.subreddit)
-        )
+        return hash(self.__class__.__name__) ^ hash(str(self)) ^ hash(self.subreddit)
 
     def __init__(
         self,
-        reddit: Reddit,
-        subreddit: Subreddit,
+        reddit: "Reddit",
+        subreddit: "Subreddit",
         name: str,
         _data: Optional[Dict[str, Any]] = None,
     ):
@@ -73,25 +67,23 @@ class Emoji(RedditBase):
                 self._fetched = True
                 return
         raise ClientException(
-            "/r/{} does not have the emoji {}".format(
-                self.subreddit, self.name
-            )
+            "/r/{} does not have the emoji {}".format(self.subreddit, self.name)
         )
 
     def delete(self):
         """Delete an emoji from this subreddit by Emoji.
 
-        To delete ``test`` as an emoji on the subreddit ``praw_test`` try:
+        To delete ``"test"`` as an emoji on the subreddit ``"praw_test"`` try:
 
         .. code-block:: python
 
-           reddit.subreddit('praw_test').emoji['test'].delete()
+           reddit.subreddit("praw_test").emoji["test"].delete()
 
         """
         url = API_PATH["emoji_delete"].format(
             emoji_name=self.name, subreddit=self.subreddit
         )
-        self._reddit.request("DELETE", url)
+        self._reddit.delete(url)
 
     def update(
         self,
@@ -158,13 +150,13 @@ class SubredditEmoji:
 
         .. code-block:: python
 
-           emoji = reddit.subreddit('praw_test').emoji['test']
+           emoji = reddit.subreddit("praw_test").emoji["test"]
            print(emoji)
 
         """
         return Emoji(self._reddit, self.subreddit, name)
 
-    def __init__(self, subreddit: Subreddit):
+    def __init__(self, subreddit: "Subreddit"):
         """Create a SubredditEmoji instance.
 
         :param subreddit: The subreddit whose emoji are affected.
@@ -180,7 +172,7 @@ class SubredditEmoji:
 
         .. code-block:: python
 
-           for emoji in reddit.subreddit('praw_test').emoji:
+           for emoji in reddit.subreddit("praw_test").emoji:
                print(emoji)
 
         """
@@ -194,9 +186,7 @@ class SubredditEmoji:
         ]
         assert len(subreddit_keys) == 1
         for emoji_name, emoji_data in response[subreddit_keys[0]].items():
-            yield Emoji(
-                self._reddit, self.subreddit, emoji_name, _data=emoji_data
-            )
+            yield Emoji(self._reddit, self.subreddit, emoji_name, _data=emoji_data)
 
     def add(
         self,
@@ -235,9 +225,7 @@ class SubredditEmoji:
 
         # until we learn otherwise, assume this request always succeeds
         upload_lease = self._reddit.post(url, data=data)["s3UploadLease"]
-        upload_data = {
-            item["name"]: item["value"] for item in upload_lease["fields"]
-        }
+        upload_data = {item["name"]: item["value"] for item in upload_lease["fields"]}
         upload_url = "https:{}".format(upload_lease["action"])
 
         with open(image_path, "rb") as image:
