@@ -15,13 +15,11 @@ class GildableMixin:
 
         .. code-block:: python
 
-           comment = reddit.comment('dkk4qjd')
+           comment = reddit.comment("dkk4qjd")
            comment.gild()
 
-           submission = reddit.submission('8dmv8z')
+           submission = reddit.submission("8dmv8z")
            submission.gild()
 
         """
-        self._reddit.post(
-            API_PATH["gild_thing"].format(fullname=self.fullname)
-        )
+        self._reddit.post(API_PATH["gild_thing"].format(fullname=self.fullname))
