@@ -1,9 +1,10 @@
 """Provide the MessageableMixin class."""
-from typing import Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Optional, Union
 
 from ....const import API_PATH
 
-Subreddit = TypeVar("Subreddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ..subreddit import Subreddit  # noqa: F401
 
 
 class MessageableMixin:
@@ -13,7 +14,7 @@ class MessageableMixin:
         self,
         subject: str,
         message: str,
-        from_subreddit: Optional[Union[Subreddit, str]] = None,
+        from_subreddit: Optional[Union["Subreddit", str]] = None,
     ):
         """
         Send a message to a redditor or a subreddit's moderators (mod mail).
@@ -30,28 +31,26 @@ class MessageableMixin:
 
         .. code-block:: python
 
-           reddit.redditor('spez').message('TEST', 'test message from PRAW')
+           reddit.redditor("spez").message("TEST", "test message from PRAW")
 
         To send a message to ``u/spez`` from the moderators of ``r/test`` try:
 
         .. code-block:: python
 
-           reddit.redditor('spez').message('TEST', 'test message from r/test',
-                                           from_subreddit='test')
+           reddit.redditor("spez").message("TEST", "test message from r/test",
+                                           from_subreddit="test")
 
         To send a message to the moderators of ``r/test``, try:
 
         .. code-block:: python
 
-           reddit.subreddit('test').message('TEST', 'test PM from PRAW')
+           reddit.subreddit("test").message("TEST", "test PM from PRAW")
 
         """
         data = {
             "subject": subject,
             "text": message,
-            "to": "{}{}".format(
-                getattr(self.__class__, "MESSAGE_PREFIX", ""), self
-            ),
+            "to": "{}{}".format(getattr(self.__class__, "MESSAGE_PREFIX", ""), self),
         }
         if from_subreddit:
             data["from_sr"] = str(from_subreddit)
