@@ -23,10 +23,10 @@ class VotableMixin:
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            submission.clear_vote()
 
-           comment = reddit.comment(id='dxolpyc')
+           comment = reddit.comment(id="dxolpyc")
            comment.clear_vote()
 
         """
@@ -45,10 +45,10 @@ class VotableMixin:
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            submission.downvote()
 
-           comment = reddit.comment(id='dxolpyc')
+           comment = reddit.comment(id="dxolpyc")
            comment.downvote()
 
         .. seealso:: :meth:`~.upvote`
@@ -69,10 +69,10 @@ class VotableMixin:
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+           submission = reddit.submission(id="5or86n")
            submission.upvote()
 
-           comment = reddit.comment(id='dxolpyc')
+           comment = reddit.comment(id="dxolpyc")
            comment.upvote()
 
         .. seealso:: :meth:`~.downvote`
