@@ -1,6 +1,6 @@
 """Provide the Redditor class."""
 from json import dumps
-from typing import Any, Dict, Generator, List, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Generator, List, Optional, Union
 
 from ...const import API_PATH
 from ...util.cache import cachedproperty
@@ -9,19 +9,16 @@ from ..util import stream_generator
 from .base import RedditBase
 from .mixins import FullnameMixin, MessageableMixin
 
-_Redditor = TypeVar("_Redditor")
-_RedditorStream = TypeVar("_RedditorStream")
-Comment = TypeVar("Comment")
-Multireddit = TypeVar("Multireddit")
-Reddit = TypeVar("Reddit")
-Submission = TypeVar("Submission")
-Subreddit = TypeVar("Subreddit")
-Trophy = TypeVar("Trophy")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import Reddit
+    from ..trophy import Trophy  # noqa: F401
+    from .comment import Comment  # noqa: F401
+    from .multi import Multireddit  # noqa: F401
+    from .submission import Submission  # noqa: F401
+    from .subreddit import Subreddit  # noqa: F401
 
 
-class Redditor(
-    MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase
-):
+class Redditor(MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase):
     """A class representing the users of reddit.
 
     **Typical Attributes**
@@ -30,7 +27,7 @@ class Redditor(
     class. Since attributes are dynamically provided (see
     :ref:`determine-available-attributes-of-an-object`), there is not a
     guarantee that these attributes will always be present, nor is this list
-    comprehensive in any way.
+    necessarily complete.
 
     .. note:: Shadowbanned accounts are treated the same as non-existent
         accounts, meaning that they will not have any attributes.
@@ -66,15 +63,15 @@ class Redditor(
     ``subreddit``                        If the Redditor has created a
                                          user-subreddit, provides a dictionary
                                          of additional attributes. See below.
-    ``subreddit['banner_img']``          The URL of the user-subreddit banner.
-    ``subreddit['name']``                The fullname of the user-subreddit.
-    ``subreddit['over_18']``             Whether or not the user-subreddit is
+    ``subreddit["banner_img"]``          The URL of the user-subreddit banner.
+    ``subreddit["name"]``                The fullname of the user-subreddit.
+    ``subreddit["over_18"]``             Whether or not the user-subreddit is
                                          NSFW.
-    ``subreddit['public_description']``  The public description of the user-
+    ``subreddit["public_description"]``  The public description of the user-
                                          subreddit.
-    ``subreddit['subscribers']``         The number of users subscribed to the
+    ``subreddit["subscribers"]``         The number of users subscribed to the
                                          user-subreddit.
-    ``subreddit['title']``               The title of the user-subreddit.
+    ``subreddit["title"]``               The title of the user-subreddit.
     ==================================== ======================================
 
 
@@ -92,7 +89,7 @@ class Redditor(
         return cls(reddit, data)
 
     @cachedproperty
-    def stream(self) -> _RedditorStream:
+    def stream(self) -> "RedditorStream":
         """Provide an instance of :class:`.RedditorStream`.
 
         Streams can be used to indefinitely retrieve new comments made by a
@@ -100,7 +97,7 @@ class Redditor(
 
         .. code-block:: python
 
-           for comment in reddit.redditor('spez').stream.comments():
+           for comment in reddit.redditor("spez").stream.comments():
                print(comment)
 
         Additionally, new submissions can be retrieved via the stream. In the
@@ -109,24 +106,24 @@ class Redditor(
 
         .. code-block:: python
 
-           for submission in reddit.redditor('spez').stream.submissions():
+           for submission in reddit.redditor("spez").stream.submissions():
                print(submission)
 
         """
         return RedditorStream(self)
 
     @property
-    def _kind(self):
+    def _kind(self) -> str:
         """Return the class's kind."""
         return self._reddit.config.kinds["redditor"]
 
     @property
-    def _path(self):
+    def _path(self) -> str:
         return API_PATH["user"].format(user=self)
 
     def __init__(
         self,
-        reddit: Reddit,
+        reddit: "Reddit",
         name: Optional[str] = None,
         fullname: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
@@ -142,8 +139,7 @@ class Redditor(
         """
         if (name, fullname, _data).count(None) != 2:
             raise TypeError(
-                "Exactly one of `name`, `fullname`, or `_data` must be "
-                "provided."
+                "Exactly one of `name`, `fullname`, or `_data` must be provided."
             )
         if _data:
             assert (
@@ -157,9 +153,9 @@ class Redditor(
             self._fullname = fullname
 
     def _fetch_username(self, fullname):
-        return self._reddit.get(
-            API_PATH["user_by_fullname"], params={"ids": fullname}
-        )[fullname]["name"]
+        return self._reddit.get(API_PATH["user_by_fullname"], params={"ids": fullname})[
+            fullname
+        ]["name"]
 
     def _fetch_info(self):
         if hasattr(self, "_fullname"):
@@ -192,9 +188,7 @@ class Redditor(
             reddit.redditor("spez").block()
 
         """
-        self._reddit.post(
-            API_PATH["block_user"], params={"account_id": self.fullname}
-        )
+        self._reddit.post(API_PATH["block_user"], params={"account_id": self.fullname})
 
     def friend(self, note: str = None):
         """Friend the Redditor.
@@ -219,7 +213,7 @@ class Redditor(
         """
         self._friend("PUT", data={"note": note} if note else {})
 
-    def friend_info(self) -> _Redditor:
+    def friend_info(self) -> "Redditor":
         """Return a Redditor instance with specific friend-related attributes.
 
         :returns: A :class:`.Redditor` instance with fields ``date``, ``id``,
@@ -251,11 +245,10 @@ class Redditor(
         if months < 1 or months > 36:
             raise TypeError("months must be between 1 and 36")
         self._reddit.post(
-            API_PATH["gild_user"].format(username=self),
-            data={"months": months},
+            API_PATH["gild_user"].format(username=self), data={"months": months},
         )
 
-    def moderated(self) -> List[Subreddit]:
+    def moderated(self) -> List["Subreddit"]:
         """Return a list of the redditor's moderated subreddits.
 
         :returns: A ``list`` of :class:`~praw.models.Subreddit` objects.
@@ -269,7 +262,7 @@ class Redditor(
 
         .. code-block:: python
 
-            for subreddit in reddit.redditor('spez').moderated():
+            for subreddit in reddit.redditor("spez").moderated():
                 print(subreddit.display_name)
                 print(subreddit.title)
 
@@ -278,12 +271,10 @@ class Redditor(
         if "data" not in modded_data:
             return []
         else:
-            subreddits = [
-                self._reddit.subreddit(x["sr"]) for x in modded_data["data"]
-            ]
+            subreddits = [self._reddit.subreddit(x["sr"]) for x in modded_data["data"]]
             return subreddits
 
-    def multireddits(self) -> List[Multireddit]:
+    def multireddits(self) -> List["Multireddit"]:
         """Return a list of the redditor's public multireddits.
 
         For example, to to get Redditor ``spez``'s multireddits:
@@ -296,11 +287,11 @@ class Redditor(
         """
         return self._reddit.get(API_PATH["multireddit_user"].format(user=self))
 
-    def trophies(self) -> List[Trophy]:
+    def trophies(self) -> List["Trophy"]:
         """Return a list of the redditor's trophies.
 
         :returns: A ``list`` of :class:`~praw.models.Trophy` objects.
-            Return ``[]`` if the redditor has no trophy.
+            Return an empty list (``[]``) if the redditor has no trophies.
 
         :raises: :class:`.RedditAPIException` if the redditor doesn't exist.
 
@@ -308,7 +299,7 @@ class Redditor(
 
         .. code-block:: python
 
-            for trophy in reddit.redditor('spez').trophies():
+            for trophy in reddit.redditor("spez").trophies():
                 print(trophy.name)
                 print(trophy.description)
 
@@ -359,7 +350,7 @@ class RedditorStream:
 
     def comments(
         self, **stream_options: Union[str, int, Dict[str, str]]
-    ) -> Generator[Comment, None, None]:
+    ) -> Generator["Comment", None, None]:
         """Yield new comments as they become available.
 
         Comments are yielded oldest first. Up to 100 historical comments will
@@ -372,7 +363,7 @@ class RedditorStream:
 
         .. code-block:: python
 
-           for comment in reddit.redditor('spez').stream.comments():
+           for comment in reddit.redditor("spez").stream.comments():
                print(comment)
 
         """
@@ -380,7 +371,7 @@ class RedditorStream:
 
     def submissions(
         self, **stream_options: Union[str, int, Dict[str, str]]
-    ) -> Generator[Submission, None, None]:
+    ) -> Generator["Submission", None, None]:
         """Yield new submissions as they become available.
 
         Submissions are yielded oldest first. Up to 100 historical submissions
@@ -393,10 +384,8 @@ class RedditorStream:
 
         .. code-block:: python
 
-           for submission in reddit.redditor('spez').stream.submissions():
+           for submission in reddit.redditor("spez").stream.submissions():
                print(submission)
 
         """
-        return stream_generator(
-            self.redditor.submissions.new, **stream_options
-        )
+        return stream_generator(self.redditor.submissions.new, **stream_options)
