@@ -57,9 +57,9 @@ class Reddit:
     .. code-block:: python
 
        import praw
-       reddit = praw.Reddit(client_id='CLIENT_ID',
-                            client_secret="CLIENT_SECRET", password='PASSWORD',
-                            user_agent='USERAGENT', username='USERNAME')
+       reddit = praw.Reddit(client_id="CLIENT_ID",
+                            client_secret="CLIENT_SECRET", password="PASSWORD",
+                            user_agent="USERAGENT", username="USERNAME")
 
     """
 
@@ -67,7 +67,7 @@ class Reddit:
     _ratelimit_regex = re.compile(r"([0-9]{1,2}) (seconds?|minutes?)")
 
     @property
-    def _next_unique(self):
+    def _next_unique(self) -> int:
         value = self._unique_counter
         self._unique_counter += 1
         return value
@@ -97,7 +97,14 @@ class Reddit:
 
     @property
     def validate_on_submit(self) -> bool:
-        """Get validate_on_submit."""
+        """Get validate_on_submit.
+
+        .. deprecated:: 7.0
+            If property :attr:`.validate_on_submit` is set to False, the
+            behavior is deprecated by Reddit. This attribute will be removed
+            around May-June 2020.
+
+        """
         value = self._validate_on_submit
         if value is False:
             warn(
@@ -175,7 +182,7 @@ class Reddit:
 
            my_session = betamax.Betamax(requests.Session())
            reddit = Reddit(..., requestor_class=JSONDebugRequestor,
-                           requestor_kwargs={'session': my_session})
+                           requestor_kwargs={"session": my_session})
 
         """
         self._core = self._authorized_core = self._read_only_core = None
@@ -210,10 +217,7 @@ class Reddit:
             "constructor, or as an environment variable."
         )
         for attribute in ("client_id", "user_agent"):
-            if getattr(self.config, attribute) in (
-                self.config.CONFIG_NOT_SET,
-                None,
-            ):
+            if getattr(self.config, attribute) in (self.config.CONFIG_NOT_SET, None):
                 raise MissingRequiredAttributeException(
                     required_message.format(attribute)
                 )
@@ -273,7 +277,7 @@ class Reddit:
 
         .. code-block:: python
 
-           reddit.live.create('title', 'description')
+           reddit.live.create("title", "description")
 
         """
 
@@ -286,7 +290,7 @@ class Reddit:
 
         .. code-block:: python
 
-           reddit.multireddit('samuraisam', 'programming')
+           reddit.multireddit("samuraisam", "programming")
 
         """
 
@@ -311,21 +315,21 @@ class Reddit:
 
         .. code-block:: python
 
-           reddit.subreddit.create('coolnewsubname')
+           reddit.subreddit.create("coolnewsubname")
 
         To obtain a lazy a :class:`.Subreddit` instance run:
 
         .. code-block:: python
 
-           reddit.subreddit('redditdev')
+           reddit.subreddit("redditdev")
 
         Note that multiple subreddits can be combined and filtered views of
         r/all can also be used just like a subreddit:
 
         .. code-block:: python
 
-           reddit.subreddit('redditdev+learnpython+botwatch')
-           reddit.subreddit('all-redditdev-learnpython')
+           reddit.subreddit("redditdev+learnpython+botwatch")
+           reddit.subreddit("all-redditdev-learnpython")
 
         """
 
@@ -395,6 +399,7 @@ class Reddit:
             "moderators": models.ModeratorsWidget,
             "more": models.MoreComments,
             "post-flair": models.PostFlairWidget,
+            "rule": models.Rule,
             "stylesheet": models.Stylesheet,
             "subreddit-rules": models.RulesWidget,
             "textarea": models.TextArea,
@@ -478,7 +483,9 @@ class Reddit:
         return models.DomainListing(self, domain)
 
     def get(
-        self, path: str, params: Optional[Union[str, Dict[str, str]]] = None
+        self,
+        path: str,
+        params: Optional[Union[str, Dict[str, Union[str, int]]]] = None,
     ):
         """Return parsed objects returned from a GET request to ``path``.
 
@@ -490,9 +497,7 @@ class Reddit:
         return self._objectify_request(method="GET", params=params, path=path)
 
     def info(
-        self,
-        fullnames: Optional[Iterable[str]] = None,
-        url: Optional[str] = None,
+        self, fullnames: Optional[Iterable[str]] = None, url: Optional[str] = None,
     ) -> Generator[Union[Subreddit, Comment, Submission], None, None]:
         """Fetch information about each item in ``fullnames`` or from ``url``.
 
@@ -519,9 +524,7 @@ class Reddit:
         if none_count > 1:
             raise TypeError("Either `fullnames` or `url` must be provided.")
         if none_count < 1:
-            raise TypeError(
-                "Mutually exclusive parameters: `fullnames`, `url`"
-            )
+            raise TypeError("Mutually exclusive parameters: `fullnames`, `url`")
 
         if fullnames is not None:
             if isinstance(fullnames, str):
@@ -549,10 +552,9 @@ class Reddit:
 
     def _objectify_request(
         self,
-        data: Optional[
-            Union[Dict[str, Union[str, Any]], bytes, IO, str]
-        ] = None,
+        data: Optional[Union[Dict[str, Union[str, Any]], bytes, IO, str]] = None,
         files: Optional[Dict[str, IO]] = None,
+        json=None,
         method: str = "",
         params: Optional[Union[str, Dict[str, str]]] = None,
         path: str = "",
@@ -563,6 +565,9 @@ class Reddit:
             of the request (default: None).
         :param files: Dictionary, filename to file (like) object mapping
             (default: None).
+        :param json: JSON-serializable object to send in the body
+            of the request with a Content-Type header of application/json
+            (default: None). If ``json`` is provided, ``data`` should not be.
         :param method: The HTTP method (e.g., GET, POST, PUT, DELETE).
         :param params: The query parameters to add to the request (default:
             None).
@@ -571,13 +576,18 @@ class Reddit:
         """
         return self._objector.objectify(
             self.request(
-                data=data, files=files, method=method, params=params, path=path
+                data=data,
+                files=files,
+                json=json,
+                method=method,
+                params=params,
+                path=path,
             )
         )
 
     def _handle_rate_limit(
         self, exception: RedditAPIException
-    ) -> Optional[Union[int]]:
+    ) -> Optional[Union[int, float]]:
         for item in exception.items:
             if item.error_type == "RATELIMIT":
                 amount_search = self._ratelimit_regex.search(item.message)
@@ -591,30 +601,49 @@ class Reddit:
                     return sleep_seconds
         return None
 
+    def delete(
+        self,
+        path: str,
+        data: Optional[Union[Dict[str, Union[str, Any]], bytes, IO, str]] = None,
+        json=None,
+    ) -> Any:
+        """Return parsed objects returned from a DELETE request to ``path``.
+
+        :param path: The path to fetch.
+        :param data: Dictionary, bytes, or file-like object to send in the body
+            of the request (default: None).
+        :param json: JSON-serializable object to send in the body
+            of the request with a Content-Type header of application/json
+            (default: None). If ``json`` is provided, ``data`` should not be.
+
+        """
+        return self._objectify_request(data=data, json=json, method="DELETE", path=path)
+
     def patch(
         self,
         path: str,
-        data: Optional[
-            Union[Dict[str, Union[str, Any]], bytes, IO, str]
-        ] = None,
+        data: Optional[Union[Dict[str, Union[str, Any]], bytes, IO, str]] = None,
+        json=None,
     ) -> Any:
         """Return parsed objects returned from a PATCH request to ``path``.
 
         :param path: The path to fetch.
         :param data: Dictionary, bytes, or file-like object to send in the body
             of the request (default: None).
+        :param json: JSON-serializable object to send in the body
+            of the request with a Content-Type header of application/json
+            (default: None). If ``json`` is provided, ``data`` should not be.
 
         """
-        return self._objectify_request(data=data, method="PATCH", path=path)
+        return self._objectify_request(data=data, method="PATCH", path=path, json=json)
 
     def post(
         self,
         path: str,
-        data: Optional[
-            Union[Dict[str, Union[str, Any]], bytes, IO, str]
-        ] = None,
+        data: Optional[Union[Dict[str, Union[str, Any]], bytes, IO, str]] = None,
         files: Optional[Dict[str, IO]] = None,
         params: Optional[Union[str, Dict[str, str]]] = None,
+        json=None,
     ) -> Any:
         """Return parsed objects returned from a POST request to ``path``.
 
@@ -625,13 +654,18 @@ class Reddit:
             (default: None).
         :param params: The query parameters to add to the request (default:
             None).
+        :param json: JSON-serializable object to send in the body
+            of the request with a Content-Type header of application/json
+            (default: None). If ``json`` is provided, ``data`` should not be.
 
         """
-        data = data or {}
+        if json is None:
+            data = data or {}
         try:
             return self._objectify_request(
                 data=data,
                 files=files,
+                json=json,
                 method="POST",
                 params=params,
                 path=path,
@@ -640,35 +674,31 @@ class Reddit:
             seconds = self._handle_rate_limit(exception=exception)
             if seconds is not None:
                 logger.debug(
-                    "Rate limit hit, sleeping for {:.2f} seconds".format(
-                        seconds
-                    )
+                    "Rate limit hit, sleeping for {:.2f} seconds".format(seconds)
                 )
                 time.sleep(seconds)
                 return self._objectify_request(
-                    data=data,
-                    files=files,
-                    method="POST",
-                    params=params,
-                    path=path,
+                    data=data, files=files, method="POST", params=params, path=path,
                 )
             raise
 
     def put(
         self,
         path: str,
-        data: Optional[
-            Union[Dict[str, Union[str, Any]], bytes, IO, str]
-        ] = None,
+        data: Optional[Union[Dict[str, Union[str, Any]], bytes, IO, str]] = None,
+        json=None,
     ):
         """Return parsed objects returned from a PUT request to ``path``.
 
         :param path: The path to fetch.
         :param data: Dictionary, bytes, or file-like object to send in the body
             of the request (default: None).
+        :param json: JSON-serializable object to send in the body
+            of the request with a Content-Type header of application/json
+            (default: None). If ``json`` is provided, ``data`` should not be.
 
         """
-        return self._objectify_request(data=data, method="PUT", path=path,)
+        return self._objectify_request(data=data, json=json, method="PUT", path=path)
 
     def random_subreddit(self, nsfw: bool = False) -> Subreddit:
         """Return a random lazy instance of :class:`~.Subreddit`.
@@ -677,9 +707,7 @@ class Reddit:
             (default: False).
 
         """
-        url = API_PATH["subreddit"].format(
-            subreddit="randnsfw" if nsfw else "random"
-        )
+        url = API_PATH["subreddit"].format(subreddit="randnsfw" if nsfw else "random")
         path = None
         try:
             self.get(url, params={"unique": self._next_unique})
@@ -705,10 +733,9 @@ class Reddit:
         method: str,
         path: str,
         params: Optional[Union[str, Dict[str, str]]] = None,
-        data: Optional[
-            Union[Dict[str, Union[str, Any]], bytes, IO, str]
-        ] = None,
+        data: Optional[Union[Dict[str, Union[str, Any]], bytes, IO, str]] = None,
         files: Optional[Dict[str, IO]] = None,
+        json=None,
     ) -> Any:
         """Return the parsed JSON data returned from a request to URL.
 
@@ -720,8 +747,13 @@ class Reddit:
             of the request (default: None).
         :param files: Dictionary, filename to file (like) object mapping
             (default: None).
+        :param json: JSON-serializable object to send in the body
+            of the request with a Content-Type header of application/json
+            (default: None). If ``json`` is provided, ``data`` should not be.
 
         """
+        if data and json:
+            raise ClientException("At most one of `data` and `json` is supported.")
         try:
             return self._core.request(
                 method,
@@ -730,6 +762,7 @@ class Reddit:
                 files=files,
                 params=params,
                 timeout=self.config.timeout,
+                json=json,
             )
         except BadRequest as exception:
             try:
@@ -741,6 +774,8 @@ class Reddit:
                     "Unexpected BadRequest without json body. Please file a "
                     "bug at https://github.com/praw-dev/praw/issues"
                 ) from exception
+            if set(data) == {"error", "message"}:
+                raise
             if "fields" in data:
                 assert len(data["fields"]) == 1
                 field = data["fields"][0]
